@@ -436,7 +436,7 @@ end
 
 function GPUInterpreter(interp::GPUInterpreter;
                         world::UInt=interp.world,
-                        method_table_view::Core.MethodTable=interp.method_table_view,
+                        method_table_view::CC.MethodTableView=interp.method_table_view,
                         token::Any=interp.token,
                         inf_cache::Vector{CC.InferenceResult}=interp.inf_cache,
                         inf_params::CC.InferenceParams=interp.inf_params,
@@ -614,7 +614,7 @@ function ci_cache_populate(interp, cache, mi, min_world, max_world)
 
         # inference should have populated our cache
         wvc = WorldView(cache, min_world, max_world)
-        @assert CC.haskey(wvc, mi)
+        @assert CC.haskey(wvc, mi) "GPUCompiler: Failed to compile method for $mi, between worlds $min_world and $max_world"
         ci = CC.getindex(wvc, mi)
 
         # if ci is rettype_const, the inference result won't have been cached
@@ -629,7 +629,8 @@ function ci_cache_populate(interp, cache, mi, min_world, max_world)
 
         # inference should have populated our cache
         wvc = WorldView(cache, min_world, max_world)
-        @assert CC.haskey(wvc, mi)
+
+        @assert CC.haskey(wvc, mi) "GPUCompiler: Failed to compile method for $mi, between worlds $min_world and $max_world"
         ci = CC.getindex(wvc, mi)
 
         # if ci is rettype_const, the inference result won't have been cached
